@@ -217,7 +217,22 @@ class S3ToStepfunctions(
         :summary: Constructs a new instance of the S3ToStepfunctions class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3ToStepfunctions.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                deploy_cloud_trail: typing.Optional[builtins.bool] = None,
+                event_rule_props: typing.Optional[typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToStepfunctionsProps(
@@ -320,7 +335,20 @@ class S3ToStepfunctionsProps:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(S3ToStepfunctionsProps.__init__)
+            def stub(
+                *,
+                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                deploy_cloud_trail: typing.Optional[builtins.bool] = None,
+                event_rule_props: typing.Optional[typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
